import java.util.*;
import java.io.*;

/** Delegate
 * <p>Delegate was created by William Denniss on 5 April 2001.
 * <p>This class has a range of handy methods
 *
 * <p>William Denniss has asserted his right under the Copyright, Designs and Patents Act 1988 to be identified as the author of this work.
 *
 * @version 1.0
 * @author William Denniss
 */

public class Delegate {

	public static final String PROGRAM_NAME = "Delegate";
	public static final String VERSION_NUMBER = "1.1";
	public static final String DATE_CREATED = "5 April 2001";	
	public static final String DATE_UPDATED = "13 April 2001";
	public static final String AUTHOR = "William Denniss";


	/** Causes the current thread to temporarily cease execution for the given number of milliseconds.
	 * Unlike the wait or sleep methods, no InterrupedException is thrown.
	 * @param milliseconds the number of milliseconds you want the current thread to temporarily cease execution.
	 */
	public static void doze (int milliseconds) {

		try	{
			Thread.sleep(milliseconds);
		} catch (InterruptedException ie) {
		}
	}	
	
	/** Adjusts a integer to a given scale, returning an integer.
	 * This method is a quick way to scale and round an integer.  Normally, when an integer is scaled the returned result is a double, which is not always desired.
	 * @param number the integer you want to scale.
	 * @param scale the number the integer is to be scaled too.
	 * @return The given number that has been scaled, and rounded to the nearest integer.
	 */	
	public static int scaleAndRound (int number, double scale) {
		return (int) Math.round(number * scale);
	}

	

	public static boolean equals (String parsedString, int position, String compareString) {
		boolean resault = new Character(parsedString.charAt(position)).toString().equalsIgnoreCase(compareString);;
		return new Character(parsedString.charAt(position)).toString().equalsIgnoreCase(compareString);
		
	}
	
	public static String carvePos(String uncarved, int position) {
		return carvePos(uncarved, position, " ");
	}

	public static String carvePos(String uncarved, int position, String delimeter) throws NullPointerException, NoSuchElementException{
		String carved = "";

		try {		
			StringTokenizer st = new StringTokenizer(uncarved,delimeter);
			for (int i=0; i<=position; i++) {
				carved = st.nextToken();
			}
		} catch (NoSuchElementException e) {
			carved = "";
		}
		return carved;
	}

	public static String [] stringCarver (String uncarved) throws NullPointerException{
		return stringCarver(uncarved, " ");
	}
	
	
	public static String [] stringCarver (String uncarved, String delimeter) throws NullPointerException{
		int counter=0;
		String waste;
		StringTokenizer st = new StringTokenizer(uncarved,delimeter);
		
		while (st.hasMoreTokens()){
			waste = st.nextToken();
			counter++;
		}
		
		st = new StringTokenizer(uncarved,delimeter);
		String [] carved = new String [counter];
		
		for (int i = 0; i<counter; i++) {
			carved[i] = st.nextToken();
		}
		
		return carved;
		
	}
	
	public static String [] linkedList2StringArray (LinkedList toConvert) {

		String [] converted = new String [toConvert.size()];
		
		for (int i = 0; i<toConvert.size(); i++) {
			converted[i] = (String) toConvert.get(i);
		}
		return converted;
		
	}
	
	public static int [] string2int (String [] strings) {
		int [] ints = new int [strings.length];
		for (int i = 0; i<strings.length; i++) {
			
			try {
				ints[i] = Integer.parseInt(strings[i]);
			} catch (Exception e) {
			}
		
		}
		
		return ints;
	
	}

	public static double [] string2double (String [] strings) {
		double [] ints = new double [strings.length];
		for (int i = 0; i<strings.length; i++) {
			
			try {
				ints[i] = Double.parseDouble(strings[i]);
			} catch (Exception e) {
			}
		
		}
		
		return ints;
	
	}
	
	public static LinkedList loadList (String filename) throws IOException{
		LinkedList fileList = new LinkedList();
		try {
			BufferedReader br = new BufferedReader(new FileReader(filename));
			String tmp;
			while (true) {
				tmp = br.readLine();
				try {
					if (!(new Character(tmp.charAt(0)).toString().equalsIgnoreCase("<") || tmp.equals("") || new Character(tmp.charAt(0)).toString().equalsIgnoreCase(";"))) {
						fileList.add(tmp); 
					}
				} catch (StringIndexOutOfBoundsException e) {
					//ignore blank lines
				}
				
			}
		
		} catch (NullPointerException e) {
			//end of the file, no problem
		}
	
		return fileList;
	}

}